
-- Initialize the variables
local _CurrentRealm = GetRealmName();
local _CurrentPlayerName = UnitName("player");



function Character_OnLoad()
	initializeCharacterRecord()
	
	CharacterRecordFrame:RegisterEvent("BANKFRAME_OPENED");
	CharacterRecordFrame:RegisterEvent("PLAYERBANKBAGSLOTS_CHANGED");
	CharacterRecordFrame:RegisterEvent("PLAYERBANKSLOTS_CHANGED");
	--CharacterRecordFrame:RegisterEvent("BANKFRAME_CLOSED");
	
	CharacterRecordFrame:RegisterEvent("PLAYER_ENTERING_WORLD");
	CharacterRecordFrame:RegisterEvent("PLAYER_LOGOUT");
	
	-- TODO: Mail in different add-on
	--CharacterRecordFrame:RegisterEvent("MAIL_SHOW");
	--CharacterRecordFrame:RegisterEvent("MAIL_CLOSED");
	
	cRecordTimeOfEvent("Character_OnLoad()")
	
	t_CharacterLoadTime = GetTime()
	print("Character_OnLoad()")
end


	-- Initialize the variables
function initializeCharacterRecord()
	
	if not CharacterRecord then
		CharacterRecord = {}
	end
	
	initTable(CharacterRecord,_CurrentRealm,_CurrentPlayerName,"EVENTS")
	initTable(CharacterRecord,_CurrentRealm,_CurrentPlayerName,"GENERAL")
	initTable(CharacterRecord,_CurrentRealm,_CurrentPlayerName,"PROFESSIONS")
	initTable(CharacterRecord,_CurrentRealm,_CurrentPlayerName,"CONTAINERS")
	
end




function Character_OnEvent(self,event,...)
	cRecordTimeOfEvent(event)
	
	if event=="PLAYER_LOGOUT" or event=="PLAYER_ENTERING_WORLD" then
		UpdateGeneralInfo()
		UpdateProfessionInfo()
	end
		
	if event=="BANKFRAME_OPENED" or event=="PLAYERBANKSLOTS_CHANGED" or event=="PLAYERBANKBAGSLOTS_CHANGED" then
		if BankFrameIsVisible() and xtimer("Character_OnEvent" .. event,3) then
			UpdateGeneralInfo()
			UpdateContainerInfo()
			UpdateHeirloomInfo()
		end
	end
	
end


local cr_eventIdNumber = 0

function cRecordTimeOfEvent(event)
	initializeCharacterRecord()
	
	CharacterRecord[_CurrentRealm][_CurrentPlayerName]["EVENTS"][event] = {}
	
	CharacterRecord[_CurrentRealm][_CurrentPlayerName]["EVENTS"][event]["time"] = time()
	CharacterRecord[_CurrentRealm][_CurrentPlayerName]["EVENTS"][event]["Event ID Number"] = cr_eventIdNumber;
	
	cr_eventIdNumber = cr_eventIdNumber + 1
end



function UpdateProfessionInfo()
	local toProf = TableOfProfessions()
	local sizeTable = tablelength(toProf)
	
	if sizeTable>0 and xtimer("UpdateProfessionInfo",45) then
		CharacterRecord[_CurrentRealm][_CurrentPlayerName]["PROFESSIONS"] = toProf
		tprint(toProf)
		
	else
		print("No Professions Found")
		
	end
end


function UpdateHeirloomInfo()
	if BankFrameIsVisible() and xtimer("UpdateHeirloomInfo",30) then
		initTable(CharacterRecord,_CurrentRealm,_CurrentPlayerName,"HEIRLOOMS")
	
		local heirT,count = parseTableForHeirlooms()
		local size = tablelength(heirT)
		
		if count==0 and size==0 then
			CharacterRecord[_CurrentRealm][_CurrentPlayerName]["HEIRLOOMS"] = nil
			print("No Heirlooms found.")
			
			
		else
			CharacterRecord[_CurrentRealm][_CurrentPlayerName]["HEIRLOOMS"] = heirT
			print("Heirlooms found: " .. ColorText(0,255,0) .. count .. ColorText() .. "   " .. ColorText(0,0,255) .. size .. ColorText())
			for k, v in pairs(heirT) do
				print(k .. " " .. ColorText(255,102,0) .. v .. ColorText() )
			end
			
		end
		
	end
end




function UpdateGeneralInfo()
	CharacterRecord[_CurrentRealm][_CurrentPlayerName]["GENERAL"] = TableOfGeneralCharacterInfo(CharacterRecord[_CurrentRealm][_CurrentPlayerName]["GENERAL"]) 
end



function UpdateContainerInfo()

	if BankFrameIsVisible() then
		CharacterRecord[_CurrentRealm][_CurrentPlayerName]["CONTAINERS"] = TableOfContainerInfo()
	end

end


function Character_OnUpdate()
	if not t_CharacterLoadTime then
		return
	end
	
	if xtimer("UpdateCharacterData",20*60) then
		UpdateGeneralInfo()
		UpdateProfessionInfo()
	end
end




